# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ppchemistrysdk_cli']

package_data = \
{'': ['*']}

install_requires = \
['numpy>=1.22.4,<2.0.0', 'typer[all]>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['ppchemistrysdk-cli = ppchemistrysdk_cli.main:app']}

setup_kwargs = {
    'name': 'ppchemistrysdk-cli',
    'version': '0.1.0',
    'description': '',
    'long_description': '# `ppchemistrysdk-cli`\n\nCommand-line interface for the PPChemistrySDK python package.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli [OPTIONS] COMMAND [ARGS]...\n```\n\n**Options**:\n\n* `--install-completion`: Install completion for the current shell.\n* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.\n* `--help`: Show this message and exit.\n\n**Commands**:\n\n* `acceptors`: Get number of acceptors from a SMILES string.\n* `alogp`: Get molecular alogP from a SMILES string.\n* `composition`: Get the molecular composition from a SMILES...\n* `donors`: Get number of donors from a SMILES string.\n* `formula`: Get the moelcular formular from a SMILES...\n* `gasteiger-charges`: Get the atomic Gasteiger partial charges from...\n* `inchi-key`: Get InChI key from a SMILES string.\n* `lipinski-acceptors`: Get number of Lipinski acceptors from a...\n* `lipinski-donors`: Get number of Lipinski donors from a SMILES...\n* `lipinski-violations`: Get number of Lipinski violations from a...\n* `mass`: Get the molecular mass from a SMILES string.\n* `nema-key`: Get Nema key from a SMILES string.\n* `ref`: Get molecular reference from a SMILES string.\n* `rotational-bonds`: Get number of rotational bonds from a SMILES...\n* `surface`: Get the molecular surface from a SMILES...\n* `volume`: Get the molecular volume from a SMILES...\n* `weight`: Get the molecular weight from a SMILES...\n\n## `ppchemistrysdk-cli acceptors`\n\nGet number of acceptors from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nNumber of acceptors.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli acceptors [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli alogp`\n\nGet molecular alogP from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular alogP.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli alogp [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli composition`\n\nGet the molecular composition from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular composition.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli composition [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli donors`\n\nGet number of donors from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nNumber of donors.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli donors [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli formula`\n\nGet the moelcular formular from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular formular.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli formula [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli gasteiger-charges`\n\nGet the atomic Gasteiger partial charges from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nAtomic Gasteiger partial charges.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli gasteiger-charges [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli inchi-key`\n\nGet InChI key from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nInChI key.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli inchi-key [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli lipinski-acceptors`\n\nGet number of Lipinski acceptors from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nNumber of Lipinski acceptors.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli lipinski-acceptors [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli lipinski-donors`\n\nGet number of Lipinski donors from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nNumber of Lipinski donors.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli lipinski-donors [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli lipinski-violations`\n\nGet number of Lipinski violations from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nNumber of Lipinski violations.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli lipinski-violations [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli mass`\n\nGet the molecular mass from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular mass.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli mass [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli nema-key`\n\nGet Nema key from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nNema key.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli nema-key [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli ref`\n\nGet molecular reference from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular reference.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli ref [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli rotational-bonds`\n\nGet number of rotational bonds from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nNumber of rotational bonds.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli rotational-bonds [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli surface`\n\nGet the molecular surface from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular surface.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli surface [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli volume`\n\nGet the molecular volume from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular volume.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli volume [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n\n## `ppchemistrysdk-cli weight`\n\nGet the molecular weight from a SMILES string.\n\nArgs:\nsmiles: SMILES string (str)\n\nReturns:\nMolecular weight.\n\n**Usage**:\n\n```console\n$ ppchemistrysdk-cli weight [OPTIONS] SMILES\n```\n\n**Arguments**:\n\n* `SMILES`: [required]\n\n**Options**:\n\n* `--help`: Show this message and exit.\n',
    'author': 'Eike Caldeweyher',
    'author_email': 'e.caldeweyher@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
